aboutsummaryrefslogtreecommitdiff
path: root/src/di_container/asynchronous/binding/scope_configurator.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/di_container/asynchronous/binding/scope_configurator.rs')
-rw-r--r--src/di_container/asynchronous/binding/scope_configurator.rs58
1 files changed, 37 insertions, 21 deletions
diff --git a/src/di_container/asynchronous/binding/scope_configurator.rs b/src/di_container/asynchronous/binding/scope_configurator.rs
index 2b0f0b3..fd42fea 100644
--- a/src/di_container/asynchronous/binding/scope_configurator.rs
+++ b/src/di_container/asynchronous/binding/scope_configurator.rs
@@ -1,31 +1,38 @@
//! Scope configurator for a binding for types inside of a [`AsyncDIContainer`].
use std::marker::PhantomData;
use std::sync::Arc;
use crate::di_container::asynchronous::binding::when_configurator::AsyncBindingWhenConfigurator;
+use crate::di_container::asynchronous::IAsyncDIContainer;
use crate::errors::async_di_container::AsyncBindingScopeConfiguratorError;
use crate::interfaces::async_injectable::AsyncInjectable;
use crate::provider::r#async::{AsyncSingletonProvider, AsyncTransientTypeProvider};
use crate::ptr::ThreadsafeSingletonPtr;
-use crate::AsyncDIContainer;
-/// Scope configurator for a binding for type 'Interface' inside a [`AsyncDIContainer`].
-pub struct AsyncBindingScopeConfigurator<Interface, Implementation>
+/// Scope configurator for a binding for type 'Interface' inside a [`IAsyncDIContainer`].
+///
+/// [`IAsyncDIContainer`]: crate::di_container::asynchronous::IAsyncDIContainer
+pub struct AsyncBindingScopeConfigurator<Interface, Implementation, DIContainerType>
where
Interface: 'static + ?Sized + Send + Sync,
- Implementation: AsyncInjectable,
+ Implementation: AsyncInjectable<DIContainerType>,
+ DIContainerType: IAsyncDIContainer,
{
- di_container: Arc<AsyncDIContainer>,
+ di_container: Arc<DIContainerType>,
interface_phantom: PhantomData<Interface>,
implementation_phantom: PhantomData<Implementation>,
}
-impl<Interface, Implementation> AsyncBindingScopeConfigurator<Interface, Implementation>
+impl<Interface, Implementation, DIContainerType>
+ AsyncBindingScopeConfigurator<Interface, Implementation, DIContainerType>
where
Interface: 'static + ?Sized + Send + Sync,
- Implementation: AsyncInjectable,
+ Implementation: AsyncInjectable<DIContainerType>,
+ DIContainerType: IAsyncDIContainer,
{
- pub(crate) fn new(di_container: Arc<AsyncDIContainer>) -> Self
+ pub(crate) fn new(di_container: Arc<DIContainerType>) -> Self
{
Self {
di_container,
@@ -37,14 +44,18 @@ where
/// Configures the binding to be in a transient scope.
///
/// This is the default.
- pub async fn in_transient_scope(&self) -> AsyncBindingWhenConfigurator<Interface>
+ pub async fn in_transient_scope(
+ &self,
+ ) -> AsyncBindingWhenConfigurator<Interface, DIContainerType>
{
- let mut bindings_lock = self.di_container.bindings.lock().await;
-
- bindings_lock.set::<Interface>(
- None,
- Box::new(AsyncTransientTypeProvider::<Implementation>::new()),
- );
+ self.di_container
+ .set_binding::<Interface>(
+ None,
+ Box::new(
+ AsyncTransientTypeProvider::<Implementation, DIContainerType>::new(),
+ ),
+ )
+ .await;
AsyncBindingWhenConfigurator::new(self.di_container.clone())
}
@@ -55,7 +66,10 @@ where
/// Will return Err if resolving the implementation fails.
pub async fn in_singleton_scope(
&self,
- ) -> Result<AsyncBindingWhenConfigurator<Interface>, AsyncBindingScopeConfiguratorError>
+ ) -> Result<
+ AsyncBindingWhenConfigurator<Interface, DIContainerType>,
+ AsyncBindingScopeConfiguratorError,
+ >
{
let singleton: ThreadsafeSingletonPtr<Implementation> =
ThreadsafeSingletonPtr::from(
@@ -66,10 +80,12 @@ where
)?,
);
- let mut bindings_lock = self.di_container.bindings.lock().await;
-
- bindings_lock
- .set::<Interface>(None, Box::new(AsyncSingletonProvider::new(singleton)));
+ self.di_container
+ .set_binding::<Interface>(
+ None,
+ Box::new(AsyncSingletonProvider::new(singleton)),
+ )
+ .await;
Ok(AsyncBindingWhenConfigurator::new(self.di_container.clone()))
}
@@ -1,31 +1,38 @@
-//! Scope configurator for a binding for types inside of a [`AsyncDIContainer`].
+//! Scope configurator for a binding for types inside of a [`IAsyncDIContainer`].
+//!
+//! [`IAsyncDIContainer`]: crate::di_container::asynchronous::IAsyncDIContainer
use std::marker::PhantomData;
use std::sync::Arc;